@@ -33,7 +33,7 @@ class Project:
     def __repr__(self):
         return f'<Project [{self.uuid}]>'
 
-    def __init__(self, api, uuid: str) -> None:
+    def __init__(self, api, uuid: str):
         self.api = api
         self.uuid = uuid
         self._node_list: List[Node] = []
@@ -49,12 +49,26 @@ class Project:
             headers={'sid': self.api.sid} if self.api.sid else None,
         )['nodes']
 
-    def get_execution_stats(self) -> List[Node]:
+    def get_execution_stats(self, skip_hidden: Optional[bool] = None) -> List[Node]:
         """Returns nodes execution statistics.
 
+        :param skip_hidden: Return statistics only of nodes in the project (i.e.
+            exclude publication and compound nodes).
+
         .. versionadded:: 0.15.0
+        .. versionchanged:: 0.25.0
+           Added `skip_hidden` optional parameter.
         """
-        return self.api.get('project/execution-statistics', params={'prjUUID': self.uuid})['nodes']
+        params = {'prjUUID': self.uuid}
+        if skip_hidden is not None:
+            params['skipHiddenNodes'] = 'true' if skip_hidden else 'false'
+        try:
+            return self.api.get('project/execution-statistics', params=params)['nodes']
+        except APIException as exc:
+            if 'redundant parameter in query' in str(exc):
+                raise APIException(
+                    "Current PolyAnalyst server doesn't support `skip_hidden` parameter, try again without it."
+                )
 
     def get_tasks(self) -> List[Dict[str, Any]]:
         """Returns task list info."""
@@ -177,7 +191,7 @@ class Project:
 
         :param force_unload: Delete project regardless other users
 
-        By default the project will be deleted only if it's not loaded to memory.
+        By default, the project will be deleted only if it's not loaded to memory.
         To delete the project that loaded to memory (there are users working on
         this project right now) set ``force_unload`` to ``True``.
         This operation available only for project owner and administrators, and
@@ -443,16 +457,33 @@ class DataSet:
         """Get dataset progress."""
         return self._api.get('dataset/progress', params={'wrapperGuid': self.guid})
 
-    def preview(self) -> _DataSet:
-        """Returns first 1000 rows with strings truncated to 250 characters."""
-        return self._api.get(
-            'dataset/preview',
-            params={
-                'prjUUID': self._prj.uuid,
-                'name': self._node['name'],
-                'type': self._node['type'],
-            },
-        )
+    def preview(self, precision: int = 6, include_blank_cells: bool = False) -> _DataSet:
+        """
+        Get dataset preview.
+
+        Contains the first 1000 rows, string/text are cut off after 250 symbols.
+        By default, numbers are rounded to 6 significant digits and blank cells are omitted.
+
+        :param precision: (optional) number of significant digits. 6 by default.
+        :param include_blank_cells: (optional) include blank cells in dataset. False by default.
+
+        :raises: APIException if non-default parameters are used with the old version of server,
+            which doesn't support them. In this case retry the method with default parameters.
+
+        .. versionadded:: 0.24.0
+            The *precision* and *include_blank_cells* parameters.
+        """
+        params = {
+            'prjUUID': self._prj.uuid,
+            'name': self._node['name'],
+            'type': self._node['type'],
+        }
+        if precision != 6:
+            params['precision'] = precision
+        if include_blank_cells is not False:
+            params['writeEmptyValues'] = include_blank_cells
+
+        return self._api.get('dataset/preview', params=params)
 
     def iter_rows(
         self, start: int = 0, stop: Optional[int] = None
